@@ -206,13 +206,7 @@ void FavoriteCollectionWidget::slotGeneralFontChanged()
 
 void FavoriteCollectionWidget::readConfig()
 {
-    // Custom/System font support
-    if (!MessageCore::MessageCoreSettings::self()->useDefaultFonts()) {
-        KConfigGroup fontConfig(KernelIf->config(), "Fonts");
-        setFont(fontConfig.readEntry("folder-font", QFontDatabase::systemFont(QFontDatabase::GeneralFont)));
-    } else {
-        setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
-    }
+    setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
 
     int iIconSize = MailCommon::MailCommonSettings::self()->iconSize();
     if (iIconSize < 16 || iIconSize > 32) {
